import { AbstractCache } from './AbstractCache';
import type { GroupCache, IdResolver } from './types/DataSources';
import type { GetManyResult, SynchronousGroupCache } from './types/SyncDataSources';
import type { InMemoryGroupCacheConfiguration } from './memory/InMemoryGroupCache';
import type { GroupNotificationPublisher } from './notifications/GroupNotificationPublisher';
export declare abstract class AbstractGroupCache<LoadedValue, ResolveParams = undefined> extends AbstractCache<LoadedValue, Map<string, Promise<LoadedValue | undefined | null> | undefined>, GroupCache<LoadedValue>, SynchronousGroupCache<LoadedValue>, InMemoryGroupCacheConfiguration, GroupNotificationPublisher<LoadedValue>> {
    isGroupCache(): boolean;
    invalidateCacheForGroup(group: string): Promise<void>;
    getInMemoryOnly(key: string, group: string, resolveParams?: ResolveParams): LoadedValue | undefined | null;
    getManyInMemoryOnly(keys: string[], group: string): GetManyResult<LoadedValue>;
    getAsyncOnly(key: string, group: string, resolveParams?: ResolveParams): Promise<LoadedValue | undefined | null>;
    getManyAsyncOnly(keys: string[], group: string, idResolver: IdResolver<LoadedValue>, resolveParams?: ResolveParams): Promise<GetManyResult<LoadedValue>>;
    get(key: string, group: string, resolveParams?: ResolveParams): Promise<LoadedValue | undefined | null>;
    getMany(keys: string[], group: string, idResolver: IdResolver<LoadedValue>, resolveParams?: ResolveParams): Promise<LoadedValue[]>;
    invalidateCacheFor(key: string, group: string): Promise<void>;
    protected resolveGroupValue(key: string, group: string, _resolveParams?: ResolveParams): Promise<LoadedValue | undefined | null>;
    protected resolveManyGroupValues(keys: string[], group: string, _idResolver: IdResolver<LoadedValue>, _resolveParams?: ResolveParams): Promise<GetManyResult<LoadedValue>>;
    protected resolveGroupLoads(group: string): Map<any, any>;
    protected deleteGroupRunningLoad(groupLoads: Map<string, unknown>, group: string, key: string): void;
}
