import type { CommonCacheConfig } from './AbstractCache';
import type { Cache, DataSource, GroupCache, IdResolver } from './types/DataSources';
import { AbstractFlatCache } from './AbstractFlatCache';
import type { InMemoryCacheConfiguration } from './memory';
import type { InMemoryGroupCacheConfiguration } from './memory/InMemoryGroupCache';
import type { SynchronousCache, SynchronousGroupCache, GetManyResult } from './types/SyncDataSources';
import type { NotificationPublisher } from './notifications/NotificationPublisher';
import type { GroupNotificationPublisher } from './notifications/GroupNotificationPublisher';
export type LoaderConfig<LoadedValue, CacheType extends Cache<LoadedValue> | GroupCache<LoadedValue> = Cache<LoadedValue>, LoaderParams = undefined, DataSourceType = DataSource<LoadedValue, LoaderParams>, InMemoryCacheConfigType extends InMemoryCacheConfiguration | InMemoryGroupCacheConfiguration = InMemoryCacheConfiguration, InMemoryCacheType extends SynchronousCache<LoadedValue> | SynchronousGroupCache<LoadedValue> = SynchronousCache<LoadedValue>, NotificationPublisherType extends NotificationPublisher<LoadedValue> | GroupNotificationPublisher<LoadedValue> = NotificationPublisher<LoadedValue>> = {
    dataSources?: readonly DataSourceType[];
    throwIfLoadError?: boolean;
    throwIfUnresolved?: boolean;
} & CommonCacheConfig<LoadedValue, CacheType, InMemoryCacheConfigType, InMemoryCacheType, NotificationPublisherType>;
export declare class Loader<LoadedValue, LoaderParams = undefined> extends AbstractFlatCache<LoadedValue, LoaderParams> {
    private readonly dataSources;
    private readonly isKeyRefreshing;
    protected readonly throwIfLoadError: boolean;
    protected readonly throwIfUnresolved: boolean;
    constructor(config: LoaderConfig<LoadedValue, Cache<LoadedValue>, LoaderParams>);
    protected resolveValue(key: string, loadParams?: LoaderParams): Promise<LoadedValue | undefined | null>;
    private loadFromLoaders;
    protected resolveManyValues(keys: string[], idResolver: IdResolver<LoadedValue>, loadParams?: LoaderParams): Promise<GetManyResult<LoadedValue>>;
    private loadManyFromLoaders;
}
