"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createGroupNotificationPair = void 0;
const node_crypto_1 = require("node:crypto");
const RedisGroupNotificationPublisher_1 = require("./RedisGroupNotificationPublisher");
const RedisGroupNotificationConsumer_1 = require("./RedisGroupNotificationConsumer");
function createGroupNotificationPair(config) {
    const serverUuid = (0, node_crypto_1.randomUUID)();
    if (config.publisherRedis === config.consumerRedis) {
        throw new Error('Same Redis client instance cannot be used both for publisher and for consumer, please create a separate connection');
    }
    const consumer = new RedisGroupNotificationConsumer_1.RedisGroupNotificationConsumer(config.consumerRedis, {
        channel: config.channel,
        serverUuid,
    });
    const publisher = new RedisGroupNotificationPublisher_1.RedisGroupNotificationPublisher(config.publisherRedis, {
        channel: config.channel,
        errorHandler: config.errorHandler,
        serverUuid,
    });
    return {
        publisher,
        consumer,
    };
}
exports.createGroupNotificationPair = createGroupNotificationPair;
//# sourceMappingURL=RedisGroupNotificationFactory.js.map